# coms4995-oss
A semester-long project for coms4995 - Open Source Software Development


## Ideas

* My first idea was to create a program that can generate static websites from markdown composed files. It would also allow you to create your own template.

* A python library for one functional feature such as lazy lists or immutable data structures. However, I found [PyFunctional](https://github.com/EntilZha/PyFunctional) and [Pyrsistent](https://pyrsistent.readthedocs.io/en/latest/), which seem to be very mature libraries. I might still try to implement something more specific.

I would also love some suggestions if you have any. After looking at your streams library I was inspired to something cool with python.

## Team Members

- Yefri Gaitan [@yefrig](https://github.com/yefrig)

 - Ecenaz (Jen) Ozmen [@eozmen410](https://github.com/eozmen410)
